jenkins-bot merged this change.

View Change

Approvals: Dvorapa: Looks good to me, approved jenkins-bot: Verified
[cleanup] Desupport functions dealing with stars list

stars lists functionality was replaced by wikidata
and related templates where deleted around 2015

Change-Id: I8da14f8d1646eb7322daccb612cb7d573224089e
---
M pywikibot/textlib.py
1 file changed, 7 insertions(+), 3 deletions(-)

diff --git a/pywikibot/textlib.py b/pywikibot/textlib.py
index 8a7a10c..5cb8f63 100644
--- a/pywikibot/textlib.py
+++ b/pywikibot/textlib.py
@@ -1915,9 +1915,9 @@
return '{{%s\n%s}}' % (template, text)


# ---------------------------------
# functions dealing with stars list
# ---------------------------------

starsList = [
'bueno',
@@ -1950,6 +1950,7 @@
]


+@deprecated(future_warning=True, since='20200324')
def get_stars(text):
"""
Extract stars templates from wikitext.
@@ -1970,6 +1971,7 @@
return allstars


+@deprecated(future_warning=True, since='20200324')
def remove_stars(text, stars_list):
"""
Remove stars templates from text.
@@ -1985,6 +1987,7 @@
return text


+@deprecated(future_warning=True, since='20200324')
def append_stars(text, stars_list, site=None):
"""
Remove stars templates from text.
@@ -2009,6 +2012,7 @@
return text


+@deprecated(future_warning=True, since='20200324')
def standardize_stars(text):
"""Make sure that star templates are in the right order."""
allstars = get_stars(text)
@@ -1915,9 +1915,9 @@


-# ---------------------------------
-# functions dealing with stars list
-# ---------------------------------
+# ----------------------------------------------
+# functions dealing with stars list (deprecated)
+# ----------------------------------------------

starsList = [

To view, visit change 583107. To unsubscribe, or for help writing mail filters, visit settings.

Gerrit-Project: pywikibot/core
Gerrit-Branch: master
Gerrit-MessageType: merged
Gerrit-Change-Id: I8da14f8d1646eb7322daccb612cb7d573224089e
Gerrit-Change-Number: 583107
Gerrit-PatchSet: 3
Gerrit-Owner: Xqt <info@gno.de>
Gerrit-Reviewer: Dvorapa <dvorapa@seznam.cz>
Gerrit-Reviewer: jenkins-bot (75)